sqlobject.tests.test_joins module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_joins module

class `sqlobject.tests.test_joins.` `AddressJoiner`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `addPersonJoiner`(obj)
  classmethod `byZip`(val, connection=None)
  `j` = address_joiner
  property `personJoiners`
  `q` = address_joiner
  `removePersonJoiner`(obj)
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = [<sqlobject.joins.RelatedJoin object>]
    `joins` = [<sqlobject.joins.SORelatedJoin object>]
    `soClass`

      alias of `sqlobject.tests.test_joins.AddressJoiner`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'address_joiner'
  property `zip`

class `sqlobject.tests.test_joins.` `AddressJoiner2`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = address_joiner2
  property `personJoiner2`
  property `personJoiner2ID`
  property `plus4`
  `q` = address_joiner2
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `defaultOrder` = ['-zip', 'plus4']
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_joins.AddressJoiner2`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'address_joiner2'
  property `zip`

class `sqlobject.tests.test_joins.` `AddressJoiner3`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = address_joiner3
  property `personJoiner3`
  property `personJoiner3ID`
  `q` = address_joiner3
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_joins.AddressJoiner3`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'address_joiner3'
  property `zip`

class `sqlobject.tests.test_joins.` `ExplicitJoiningSO`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `foo`
  `j` = explicit_joining_s_o
  `q` = explicit_joining_s_o
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = [<sqlobject.joins.MultipleJoin object>]
    `joins` = [<sqlobject.joins.SOMultipleJoin object>]
    `soClass`

      alias of `sqlobject.tests.test_joins.ExplicitJoiningSO`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'explicit_joining_s_o'

class `sqlobject.tests.test_joins.` `ImplicitJoiningSO`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `addBar`(obj)
  property `foo`
  `j` = implicit_joining_s_o
  `q` = implicit_joining_s_o
  `removeBar`(obj)
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = [<sqlobject.joins.RelatedJoin object>]
    `joins` = [<sqlobject.joins.SORelatedJoin object>]
    `soClass`

      alias of `sqlobject.tests.test_joins.ImplicitJoiningSO`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'implicit_joining_s_o'

class `sqlobject.tests.test_joins.` `PersonJoiner`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `addAddressJoiner`(obj)
  property `addressJoiners`
  classmethod `byName`(val, connection=None)
  `j` = person_joiner
  property `name`
  `q` = person_joiner
  `removeAddressJoiner`(obj)
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = [<sqlobject.joins.RelatedJoin object>]
    `joins` = [<sqlobject.joins.SORelatedJoin object>]
    `soClass`

      alias of `sqlobject.tests.test_joins.PersonJoiner`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'person_joiner'

class `sqlobject.tests.test_joins.` `PersonJoiner2`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `addressJoiner2s`
  classmethod `byName`(val, connection=None)
  `j` = person_joiner2
  property `name`
  `q` = person_joiner2
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = [<sqlobject.joins.MultipleJoin object>]
    `joins` = [<sqlobject.joins.SOMultipleJoin object>]
    `soClass`

      alias of `sqlobject.tests.test_joins.PersonJoiner2`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'person_joiner2'

class `sqlobject.tests.test_joins.` `PersonJoiner3`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `addressJoiner3s`
  classmethod `byName`(val, connection=None)
  `j` = person_joiner3
  property `name`
  `q` = person_joiner3
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = [<sqlobject.joins.MultipleJoin object>]
    `joins` = [<sqlobject.joins.SOMultipleJoin object>]
    `soClass`

      alias of `sqlobject.tests.test_joins.PersonJoiner3`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'person_joiner3'

class `sqlobject.tests.test_joins.` `TestJoin`

  Bases: `object`

  `assertNamesEqual`(people, dest)
  `assertZipsEqual`(zips, dest)
  `setup_method`(meth)
  `test_join`()
  `test_joinAttributeWithUnderscores`()

class `sqlobject.tests.test_joins.` `TestJoin2`

  Bases: `object`

  `setup_method`(meth)
  `test_basic`()
  `test_defaultOrder`()

class `sqlobject.tests.test_joins.` `TestJoin3`

  Bases: `object`

  `setup_method`(meth)
  `test_accessors`()